summaryrefslogtreecommitdiff
path: root/cloudinit/config/cc_rightscale_userdata.py
diff options
context:
space:
mode:
authorharlowja <harlowja@virtualbox.rhel>2012-06-21 09:12:16 -0700
committerharlowja <harlowja@virtualbox.rhel>2012-06-21 09:12:16 -0700
commit0c83ff5cb81b6de3028cf90e7dd6aba565682dbf (patch)
treea499408fa70a248b32f0e82e36b9ae893dce46e9 /cloudinit/config/cc_rightscale_userdata.py
parent64f1347cb8f2580339d539b7772e7872ed81cae9 (diff)
downloadvyos-cloud-init-0c83ff5cb81b6de3028cf90e7dd6aba565682dbf.tar.gz
vyos-cloud-init-0c83ff5cb81b6de3028cf90e7dd6aba565682dbf.zip
1. Renames for debug message from 'transform' to 'module'
2. Fixing up more cloud.path.joins found to use the right ro/rw filename
Diffstat (limited to 'cloudinit/config/cc_rightscale_userdata.py')
-rw-r--r--cloudinit/config/cc_rightscale_userdata.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/cloudinit/config/cc_rightscale_userdata.py b/cloudinit/config/cc_rightscale_userdata.py
index 8385e281..7a134569 100644
--- a/cloudinit/config/cc_rightscale_userdata.py
+++ b/cloudinit/config/cc_rightscale_userdata.py
@@ -53,13 +53,13 @@ def handle(name, _cfg, cloud, log, _args):
try:
ud = cloud.get_userdata_raw()
except:
- log.warn("Failed to get raw userdata in transform %s", name)
+ log.warn("Failed to get raw userdata in module %s", name)
return
try:
mdict = parse_qs(ud)
if not mdict or not MY_HOOKNAME in mdict:
- log.debug(("Skipping transform %s, "
+ log.debug(("Skipping module %s, "
"did not find %s in parsed"
" raw userdata"), name, MY_HOOKNAME)
return
@@ -73,7 +73,7 @@ def handle(name, _cfg, cloud, log, _args):
# These will eventually be then ran by the cc_scripts_user
# TODO: maybe this should just be a new user data handler??
# Instead of a late transform that acts like a user data handler?
scripts_d = cloud.get_ipath_cur('scripts')
urls = mdict[MY_HOOKNAME]
for (i, url) in enumerate(urls):
@@ -73,7 +73,7 @@ def handle(name, _cfg, cloud, log, _args):
# These will eventually be then ran by the cc_scripts_user
# TODO: maybe this should just be a new user data handler??
- # Instead of a late transform that acts like a user data handler?
+ # Instead of a late module that acts like a user data handler?
scripts_d = cloud.get_ipath_cur('scripts')
urls = mdict[MY_HOOKNAME]